VideoNode

Struct VideoNode 

pub struct VideoNode { /* private fields */ }

Implementations

Source

impl VideoNode

pub unsafe fn from_ptr(ptr: *mut VSNode, api: Api) -> Self

Safety

The caller must ensure that ptr is a valid pointer to a ffi::VSNode that represents a video node.

pub fn info(&self) -> &VideoInfo

pub fn new<F: Filter>( name: &str, info: &VideoInfo, filter: F, dependencies: &[VSFilterDependency], core: impl AsRef<Core>, ) -> Option<Self>

Panics

Panics if the the dependency index is larger than i32::MAX.