pub type RequestPattern = VSRequestPattern;Aliased Type
#[repr(C)]pub enum RequestPattern {
General = 0,
NoFrameReuse = 1,
StrictSpatial = 2,
FrameReuseLastOnly = 3,
}Variants
General = 0
Anything goes. Note that filters that may be requesting beyond the end of a
[VSNode] length in frames (repeating the last frame) should use
[VSRequestPattern::General]) and not any of the other modes.
NoFrameReuse = 1
Will only request an input frame at most once if all output frames are requested
exactly one time. This includes filters such as Trim, Reverse, SelectEvery.
StrictSpatial = 2
Only requests frame N to output frame N. The main difference to
[VSRequestPattern::NoFrameReuse] is that the requested frame
is always fixed and known ahead of time. Filter examples
Lut, Expr (conditionally, see [VSRequestPattern::General] note)
and similar.
FrameReuseLastOnly = 3
Basically identical to [VSRequestPattern::NoFrameReuse] except that it hints
the last frame may be requested multiple times. Added in API 4.1.